.. _ref-core:

Core Classes
============

.. toctree::
   :maxdepth: 2
   :caption: The core classes of Webware for Python 3 are:

   application
   configurableforserversidepath
   cookie
   exceptionhandler
   httpcontent
   httpexceptions
   httprequest
   httpresponse
   httpservlet
   importmanager
   jsonrpcservlet
   page
   picklerpcservlet
   plugin
   properties
   request
   response
   rpcservlet
   servlet
   servletfactory
   session
   sessiondynamicstore
   sessionfilestore
   sessionmemcachedstore
   sessionmemorystore
   sessionredisstore
   sessionshelvestore
   sessionstore
   sidebarpage
   transaction
   unknownfiletypeservlet
   urlparser
   wsgistreamout
   xmlrpcservlet
